@@ -26,7 +26,7 @@ static bool get_one_list(int rootnumber, FILE *f, fileinfo **list, int *n)
   /* Read lines until a line with a dot or an error */
   while ((line = getline_chomp(f)) && strcmp(line, ".") && line[0] != '?')
     if (ok) {
-      if (!(*list = realloc(*list, (*n + 1) * sizeof(**list)))) {
+      if (!(*list = realloc_more(*list, *n))) {
 	warn(NULL); ok = false;
       } else if (sscanf(line, "%c %o %ld %lld%c%n", &(*list)[*n].status,
 			&(*list)[*n].mode, &(*list)[*n].time, &(*list)[*n].size,
