@@ -73,7 +73,8 @@ EXPORT typedef struct profile {
   bool nocase;			/* True if a target is case-insensitive */
   Pattern patterns;		/* Patterns to include/eclude files by name */
   time_t start;			/* For progress meter: start time of sync */
-  long long ntotal, ntodo;	/* For progress meter: total & remaining bytes */
+  long long nbtotal, nbtodo;	/* For progress meter: total & remaining bytes */
+  int nftotal, nftodo;		/* For progress meter: total & remaining files */
   long long sent1, sent2;	/* For statistics: initial bytes sent */
   char conflict_resolution;	/* Option -c */
 } *Profile;
@@ -107,7 +108,8 @@ EXPORT void init_profile(Profile p)
   p->use_shortcuts = true;
   p->patterns = NULL;
   p->start = 0;
-  p->ntotal = p->ntodo = 0;
+  p->nbtotal = p->nbtodo = 0;
+  p->nftotal = p->nftodo = 0;
   p->conflict_resolution = '/';
 }
 
