@@ -44,6 +44,9 @@
 #include "c-profile.e"
 #include "export.h"
 
+#define DELBYTES 100	      /* How many bytes to count for a deleted file */
+EXPORTDEF(DELBYTES)
+
 /* -2 = SIGWINCH handler not initialized
    -1 = window size unknown, probably not a TTY
     0 = window size not yet determined
@@ -68,11 +71,12 @@ EXPORT bool init_progress_meter(Profile profile,
   int i;
 
   /* Compute the total number of bytes to synchronize */
-  profile->ntotal = 0;
-  for (i = 0; i < nsend1; i++) profile->ntotal += send1[i].size;
-  for (i = 0; i < nsend2; i++) profile->ntotal += send2[i].size;
-  profile->ntotal += ndelete;	/* A deleted file counts as 1 byte */
-  profile->ntodo = profile->ntotal;
+  profile->nbtotal = 0;
+  for (i = 0; i < nsend1; i++) profile->nbtotal += send1[i].size;
+  for (i = 0; i < nsend2; i++) profile->nbtotal += send2[i].size;
+  profile->nbtotal += ndelete * DELBYTES; /* A deleted file counts as DELBYTES */
+  profile->nbtodo = profile->nbtotal;
+  profile->nftotal = profile->nftodo = nsend1 + nsend2 + ndelete;
   profile->start = time(NULL);
 
   /* The following is used by print_statistics() to measure speed */
@@ -86,19 +90,24 @@ EXPORT bool init_progress_meter(Profile profile,
 /* progress_meter -- return progress display, then subtract n from bytes to sync */
 EXPORT char *progress_meter(Profile p, long long n)
 {
-  int r;
+  int r1, r2, r;
+  time_t t;
   static char x[40];
 
-  if (p->ntodo != p->ntotal) {
-    r = p->ntodo * (time(NULL) - p->start) / (p->ntotal - p->ntodo);
+  if (p->nbtodo != p->nbtotal) {
+    t = time(NULL) - p->start;			   /* Seconds since start */
+    r1 = p->nbtodo * t / (p->nbtotal - p->nbtodo); /* Remaining based on bytes */
+    r2 = p->nftodo * t / (p->nftotal - p->nftodo); /* Remaining based on files */
+    r = (r1 + r2)/2.0;				   /* Average of the two */
     if (r > 60 * 60 * 2) sprintf(x, _("%d hour ETA"), (r + 1800) / 3600);
     else if (r > 60 * 2) sprintf(x, _("%d min ETA"), (r + 30) / 60);
     else sprintf(x, _("%d s ETA"), r);
   } else {
     sprintf(x, _("--:-- ETA"));
   }
-  assert(p->ntodo >= n);
-  p->ntodo -= n;
+  assert(p->nbtodo >= n);
+  p->nbtodo -= n;
+  p->nftodo--;
   return x;
 }
 
