@@ -51,7 +51,7 @@
   hash_nget() retrieves the n-th entry for a given key. It returns a
   pointer to the data and the data's length in bytes, or NULL if there
   are fewer than n entries for the key. The first entry is entry
-  1. The order of the entries is undefined, i.e., it si not
+  1. The order of the entries is undefined, i.e., it is not
   necessarily the same as the order they were added with hash_add().
 
   The value n is meant to be small. While hash_get() is efficient,
@@ -93,7 +93,7 @@
   (non-deleted) entries that it hasn't returned yet.
 
   To iterate over all entries, in case there are multiple entries for
-  the same key, combine hash_next() and hadh_nget().
+  the same key, combine hash_next() and hash_nget().
 */
 
 #include "stdincls.h"
@@ -502,6 +502,8 @@ static bool enlarge_table(hashtable table)
       for (n = 1; (data = hash_nget(table, key, keylen, n, &datalen)); n++)
 	(void) hash_add(newtable, key, keylen, data, datalen);
 
+    assert(table->nentries == newtable->nentries);
+
     /* Destroy the old table and put the new data in its place */
     hash_destroy1(table);
     table->keys = newtable->keys;
