@@ -200,7 +200,7 @@ EXPORT bool store_close(DB db)
   hashcursor c;
   fileinfo *d;
   char *path;
-  
+
   /* Create a cursor and get the first entry. */
   if (!(c = hash_cursor(db->table))) return false;
   path = hash_next(c, &plen);
@@ -214,26 +214,34 @@ EXPORT bool store_close(DB db)
 
   } else {
 
-    /* Rewrite the file with the entries as they currently are in the table. */
-    rewind(db->f);
-    if (ftruncate(fileno(db->f), 0) != 0) {
-      warn(_("Failed to write log"));
+    char tmpname[FILENAME_MAX];
+    FILE *f;
+
+    /* Write the log to a temporary file. */
+    if (!(f = create_temp_file(db->filename, tmpname))) {
+      warn(_("Failed to write log. (Cannot create temporary file.)"));
     } else {
-      (void) print(db->f, "R2SYNC %d\n", R2SYNCSTORE);
-      (void) print(db->f, "%s\n", db->root1);
-      (void) print(db->f, "%s\n", db->root2);
+      (void) print(f, "R2SYNC %d\n", R2SYNCSTORE);
+      (void) print(f, "%s\n", db->root1);
+      (void) print(f, "%s\n", db->root2);
 
       while (path) {
 	if ((d = hash_get(db->table, path, plen, &dlen)))
 	  /* Can only fail because of an interrupt */
-	  print(db->f, "%o %ld %lld %s\n", d->mode, d->time, d->size, path);
+	  print(f, "%o %ld %lld %s\n", d->mode, d->time, d->size, path);
 	else
 	  warn(_("Failed to write log for %s"), path);
 	store_del(db, path);	/* Free allocated memory */
 	path = hash_next(c, &plen);
       }
+
+      /* Rename the temporary file, replacing the old log. */
+      if (fflush(f) == -1 ||
+	(unlink(db->filename) == -1 && errno != ENOENT) ||
+	rename(tmpname, db->filename) == -1 ||
+	fclose(f) == -1)
+	warn(_("Failed to write log. (Cannot replace old log.)"));
     }
-    (void) fclose(db->f);
   }
 
   hash_destroy(db->sumtable);
