@@ -62,22 +62,6 @@ static unsigned char base64[] = {
 };
 
 
-/* create_temp_file -- create a file with a unique name in same dir as path */
-static FILE *create_temp_file(const char *path,  char name[])
-{
-  char *p;
-  FILE *f;
-  int fd;
-
-  strcpy(name, path);
-  if ((p = strrchr(name, '/'))) p++; else p = name;
-  strcpy(p, ".r2sync-XXXXXX");
-  if ((fd = mkstemp(name)) == -1)  return NULL;
-  if (!(f = fdopen(fd, "w"))) close(fd);
-  return f;
-}
-
-
 /* generate_signature -- compute checksums, write them on out */
 static bool generate_signature(FILE *out, FILE *oldfile, size_t blocksize)
 {
