@@ -3,9 +3,10 @@
 # Use the test-case program to check if say_hello() detects if the
 # file system is case-sensitive.
 
-trap 'rm -f $LOWER $UPPER' 0
-LOWER=/tmp/test-$$-test
-UPPER=/tmp/TEST-$$-TEST
+trap 'rm -rf $TMPDIR' 0
+TMPDIR=`mktemp -d /tmp/case001-XXXXXX` || exit 1
+LOWER=$TMPDIR/test-test
+UPPER=$TMPDIR/TEST-TEST
 
 touch $LOWER			# Create a file with a lowercase name
 set -- `./test-case`		# Get the "ready ID N nocase" response into $*
