@@ -60,6 +60,10 @@ EXPORTDEF(_(String))
 EXPORTDEF(gettext_noop(String))
 EXPORTDEF(N_(String))
 
+/* Handy macro for extending an allocated array to at least n+1 items*/
+#define realloc_more(p, n) realloc((p), ((n) ? 2 * (n) : 1) * sizeof(*(p)))
+EXPORTDEF(realloc_more(p, n))
+
 
 /* cmp_fileinfo -- compare two fileinfo entries alphabetically */
 EXPORT int cmp_fileinfo(const void *a, const void *b)
@@ -102,6 +106,23 @@ EXPORT bool create_directories(char *path)
 }
 
 
+/* create_temp_file -- create a file with a unique name in same dir as path */
+EXPORT FILE* create_temp_file(const char *path,  char name[FILENAME_MAX])
+{
+  char *p;
+  FILE *f;
+  int fd;
+
+  strncpy(name, path, FILENAME_MAX - 1);
+  if ((p = strrchr(name, '/'))) p++; else p = name;
+  if (p - name > FILENAME_MAX - 1 - 7) {errno = ENAMETOOLONG; return NULL;}
+  strcpy(p, ".XXXXXX");
+  if ((fd = mkstemp(name)) == -1) return NULL;
+  if (!(f = fdopen(fd, "w"))) close(fd);
+  return f;
+}
+
+
 /* debug -- print debugging information */
 EXPORT void debug(const char *format,...)
 {
